==> orchestra-pvm-4.3.0-sources.jar: org/ow2/orchestra/pvm/internal/job/MessageImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.job;

import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.internal.model.ExecutionImpl;
import org.ow2.orchestra.pvm.job.Message;

/**
 * @author Tom Baeyens
 */
public abstract class MessageImpl<T> extends JobImpl<T> implements Message {

  private static final long serialVersionUID = 1L;

  public MessageImpl() {
  }

  public String toString() {
    return "message[" + dbid + "]";
  }

  public MessageImpl(ExecutionImpl execution) {
    this.execution = execution;
    this.processInstance = execution.getProcessInstance();
  }

  protected void unlockExecution() {
    if (execution == null) {
      throw new PvmException("This message isn't bound to any execution");
    }
    execution.unlock();
  }
}

==> orchestra-pvm-4.4.2-sources.jar: org/ow2/orchestra/pvm/internal/job/MessageImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.job;

import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.internal.model.ExecutionImpl;
import org.ow2.orchestra.pvm.job.Message;

/**
 * @author Tom Baeyens
 */
public abstract class MessageImpl<T> extends JobImpl<T> implements Message {

  private static final long serialVersionUID = 1L;

  public MessageImpl() {
  }

  @Override
  public String toString() {
    return this.getClass().getSimpleName() + "[" + this.dbid + "]";
  }

  public MessageImpl(final ExecutionImpl execution) {
    this.execution = execution;
    this.processInstance = execution.getProcessInstance();
  }

  protected void unlockExecution() {
    if (this.execution == null) {
      throw new PvmException("This message isn't bound to any execution");
    }
    this.execution.unlock();
  }
}
